using System;
using System.Collections.Generic;
using System.Linq;
using System.Text.RegularExpressions;
using System.Threading;

using Styx.Common;
using Styx.Common.Helpers;
using Styx.CommonBot;
using Styx.CommonBot.Inventory;
using Styx.Plugins;
using Styx.WoWInternals;
using Styx.WoWInternals.WoWObjects;

namespace Styx.Bot.Plugins.NoBind
{
	public partial class NoBind : HBPlugin
	{
		#region Overrides of HBPlugin
		public override void Initialize()
		{
			Logging.Write("[NoBind] Attaching to Bind Events.");
			Lua.Events.AttachEvent("EQUIP_BIND_CONFIRM", ConfirmBindEquip);
			Lua.Events.AttachEvent("AUTOEQUIP_BIND_CONFIRM", ConfirmBindEquip);
			Lua.Events.AttachEvent("LOOT_BIND_CONFIRM", ConfirmBindPickup);
			Lua.Events.AttachEvent("CONFIRM_LOOT_ROLL", ConfirmRoll);
			Lua.Events.AttachEvent("START_LOOT_ROLL", DetectRoll);
			Lua.Events.AttachEvent("CONFIRM_DISENCHANT_ROLL", ConfirmRoll);
		}
		
		public override void Dispose()
		{
			Logging.Write("[NoBind] Detaching from Bind Events");
			Lua.Events.DetachEvent("EQUIP_BIND_CONFIRM", ConfirmBindEquip);
			Lua.Events.DetachEvent("AUTOEQUIP_BIND_CONFIRM", ConfirmBindEquip);
			Lua.Events.DetachEvent("LOOT_BIND_CONFIRM", ConfirmBindPickup);
			Lua.Events.DetachEvent("CONFIRM_LOOT_ROLL", ConfirmRoll);
			Lua.Events.DetachEvent("START_LOOT_ROLL", DetectRoll);
			Lua.Events.DetachEvent("CONFIRM_DISENCHANT_ROLL", ConfirmRoll);
		}

		public override string Name { get { return "NoBind"; } }
		public override string Author { get { return "Echelon17"; } }
		public override Version Version { get { return new Version(1, 1, 0); } }
		#endregion
		
		public string rollid, rolltime, rolltype;
		
		public override void Pulse()
		{
			// This is requred I believe.
			return;
		}

		private void ConfirmBindEquip(object sender, LuaEventArgs e)
		{
			Logging.Write("[NoBind] Confirming Bind on Equip action.");
			var lootid = e.Args[0].ToString();
			Lua.DoString("EquipPendingItem(0)");
		}
		
		private void ConfirmBindPickup(object sender, LuaEventArgs e)
		{
			Logging.Write("[NoBind] Confirming Bind on Pickup action.");
			var slotid = e.Args[0].ToString();
			Lua.DoString("ConfirmLootSlot({slotid})");
		}
		
		public void DetectRoll(object sender, LuaEventArgs e)
		{
			rollid = e.Args[0].ToString();
			rolltime = e.Args[1].ToString();
			Logging.Write("[NoBind] Loot roll window detected with a roll ID of {0} and time of {1}", rollid, rolltime);
		}
		
		public void ConfirmRoll(object sender, LuaEventArgs e)
		{
			var rollmessage = "";
			rollid = e.Args[0].ToString();
			rolltype = e.Args[1].ToString();
			switch (rolltype) {
				case "0":
					rollmessage = "pass";
				break;
				case "1":
					rollmessage = "need";
				break;
				case "2":
					rollmessage = "greed";
				break;
				case "3":
					rollmessage = "disenchant";
				break;
			}
			Logging.Write("[NoBind] Confirming {0} roll on item.", rollmessage);
			Lua.DoString("ConfirmLootRoll(" + rollid + ", " + rolltype + ")");
			Logging.Write("[NoBind] Closing annoying request window");
			Lua.DoString("StaticPopup1Button1:Click()"); // Need this to close the annoying bind window
		}
	}
}